﻿using System;
using System.Management;

namespace NetworkConnectionCS
{
    /// <summary>
    /// This sample demonstrates the use of System.Management
    /// to detect whether or not one or more valid network
    /// connections is associated with the machine.
    /// </summary>
    class NetworkInformation
    {
        [STAThread]
        static void Main(string[] args)
        {
            // Check to see if there is one or more connections
            // assigned to this machine (based on IP address)
            int numConnections = GetNumAvailableConnections();
            if (numConnections > 0)
            {
                if (numConnections == 1)
                {
                    Console.WriteLine("1 connection on this machine with ");
                    Console.WriteLine("at least 1 valid IP address assigned");
                }
                else
                {
                    Console.WriteLine(numConnections + " connections on this ");
                    Console.WriteLine("machine with at least 1 valid IP address");
                }
            }
            else
            {
                Console.WriteLine("No cards found with a valid IP address");
            }
        }

        public static int GetNumAvailableConnections()
        {
            // Query for the list of network adapters on the machine
            // Note for more detail on this type you can search 
            // for "Win32_NetworkAdapterConfiguration":
            // http://msdn.microsoft.com/en-us/library/aa394217(VS.85).aspx
            SelectQuery NAQuery = new SelectQuery("select * from Win32_NetworkAdapterConfiguration");
            ManagementObjectSearcher NASearcher = new ManagementObjectSearcher(NAQuery);
            int availableConnections = 0;

            try
            {
                // Loop through each adapter returned from the query
                foreach (ManagementObject enumerate in NASearcher.Get())
                {
                    // Find out if IP is enabled on this adapter
                    bool IPEnabled = (bool)enumerate["IPEnabled"];
                    // Get the adapter description
                    Console.WriteLine((string)enumerate["Caption"]);

                    // If the IP is enabled check for non-zero IP
                    if (IPEnabled)
                    {
                        string[] IPAddress = (string[])enumerate["IPAddress"];
                        Console.WriteLine("IP Address: " + IPAddress[0]);
                        if (IPAddress[0] != "0.0.0.0")
                        {
                            availableConnections++;
                        }
                    }
                    Console.WriteLine();
                }
            }
            catch (Exception e)
            {
                Console.WriteLine(e.ToString());
            }
            return availableConnections;
        }
    }
}
